@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: text
-version: 1.2.2.0
-id: text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
-key: text_5c7VCmRXJenGcMPs3kwpkI
+version: 1.2.2.1
+id: text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
+key: text_HmqVQnZSpjaC156ABqPhne
 license: BSD3
 copyright: 2009-2011 Bryan O'\''Sullivan, 2008-2009 Tom Harper
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
@@ -64,10 +64,10 @@ exposed-modules:
     Data.Text.Read Data.Text.Unsafe
 hidden-modules: Data.Text.Show
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/text-1.2.2.0
-library-dirs: /usr/lib/ghc-7.10.3/site-local/text-1.2.2.0
-data-dir: /usr/share/arm-linux-ghc-7.10.3/text-1.2.2.0
-hs-libraries: HStext-1.2.2.0-5c7VCmRXJenGcMPs3kwpkI
+import-dirs: /usr/lib/ghc-7.10.3/site-local/text-1.2.2.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/text-1.2.2.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/text-1.2.2.1
+hs-libraries: HStext-1.2.2.1-HmqVQnZSpjaC156ABqPhne
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
